/*
 * DROIDAnyStreamByteReader.java
 *
 * Version: $Revision: 0 $
 *
 * Date: $Date: 2006-05-26 10:23:17 -0400 (Fri, 26 May 2006) $
 *
 * Copyright (c) 2002-2007, Hewlett-Packard Company and Massachusetts
 * Institute of Technology.  All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 * - Redistributions of source code must retain the above copyright
 * notice, this list of conditions and the following disclaimer.
 *
 * - Redistributions in binary form must reproduce the above copyright
 * notice, this list of conditions and the following disclaimer in the
 * documentation and/or other materials provided with the distribution.
 *
 * - Neither the name of the Hewlett-Packard Company nor the name of the
 * Massachusetts Institute of Technology nor the names of their
 * contributors may be used to endorse or promote products derived from
 * this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
 * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
 * HOLDERS OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
 * BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS
 * OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR
 * TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE
 * USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH
 * DAMAGE.
 */

package org.dspace.content.format;

import uk.gov.nationalarchives.droid.IdentificationFile;
import uk.gov.nationalarchives.droid.binFileReader.AbstractByteReader;
import uk.gov.nationalarchives.droid.binFileReader.ByteReader;
import uk.gov.nationalarchives.droid.binFileReader.StreamByteReader;
import uk.gov.nationalarchives.droid.binFileReader.FileByteReader;

import java.io.File;
import java.io.IOException;
import java.io.InputStream;

/**
 * DROIDAnyStreamByteReader - DROID ByteReader subclass that
 * reads from ANY InputStream (not just System.in), and also
 * allows an arbitrary pathname to be applied to it.  Normally, the
 * AbstractByteReader uses the path to determine which subclass to
 * create, so only the magic string "-" will create an input stream
 * reader, and it only reads from System.in.  This bypasses the whole
 * AbstractByteReader mechanism, so you have to call the static
 * factory method explicitly.
 *
 * <p> DSpace needs this reader in order to get DROID to look at the contents
 * of a Bitstream.  It only offers a stream inteface to the Bitstream content;
 * there may not even _be_ a real file in a filesystem (e.g. could be in SRB).
 * However, Bitstreams do have names which can also be used for format
 * identification or confirmation, so the name must be included too.
 *
 * <p>
 * @author Larry Stone
 * @version $Revision: 1323 $
 */
public class DROIDAnyStreamByteReader extends StreamByteReader {

    public DROIDAnyStreamByteReader(IdentificationFile theIDFile, InputStream theStream) {
        super(theIDFile);
        this.readInputStream(theStream);
    }

    /**
     * The factory method. Trys to read stream into a buffer. If it doesn't fit,
     * save it to a file, and return a FileByteReader with that file.
     */
/*** XXX purple wire
    public static ByteReader newDROIDAnyStreamByteReader(IdentificationFile theIDFile, InputStream theStream)
    {
        DROIDAnyStreamByteReader byteReader = new DROIDAnyStreamByteReader(theIDFile, theStream);
        if (byteReader.tempFile == null) {
            return byteReader;
        } else {
            *** XXX DUNSEL
            // KLUDGE:
            // In order to get a file-oriented ByteReader, we
            // temporarily set theIDFile's path to the temp file's path.
            // Then change it back after creating the ByteReader.
            // It would be easier if DROID didn't think it knows better
            // than me what kind of reader I want.
            String temp = theIDFile.getFilePath();
            theIDFile.setFilePath(byteReader.tempFile.getPath());
            ByteReader result = AbstractByteReader.newByteReader(theIDFile, true);
            theIDFile.setFilePath(temp);
            return result;
                ***

            return new FileByteReader(theIDFile, true, byteReader.tempFile.getPath());
        }
    }
***/

    private void readInputStream(InputStream in) {
        try {
            readStream(in);
        }  catch (IOException ex) {
            this.setErrorIdent();
            this.setIdentificationWarning("Input stream could not be read");
        }
    }

    // accessor for protected tempFile so DSpace FormatIdentifier
    // can clean up after DROID, which leaves temp files around.
    public File getTempFile() {
        return tempFile;
    }
}
