package org.dspace.content.format;

/**
 * Implementation representing the traditional set of coarse-grained
 * data formats in DSpace up to version 1.5.  The "registry" is contained in
 * a configuration file which is loaded into memory on startup.
 * See the documentation in BuiltinFormatRegistry for details.
 * <p>
 * Configuration entries:
 *   # path to registry contents in XML:
 *   formatRegistry.DSpace.document = ${dspace.dir}/config/formats/dspace-formats.xml
 *   # whether or not to validate registry when loading it
 *   formatRegistry.DSpace.validate = true
 *   # path to schema with which to validate
 *   formatRegistry.DSpace.schema = ${dspace.dir}/config/formats/formats.xsd
 *   # Default value of supportLevel on newly created/imported BSFs,
 *   # must be one of "unknown" | "known" | "supported"
 *   formatRegistry.DSpace.defaultSupportLevel = unknown
 * <p>
 * @author Larry Stone
 * @version $Revision: 1323 $
 * @see BuiltinFormatRegistry
 */
public class DSpaceFormatRegistry extends BuiltinFormatRegistry
{
    public static final String NAMESPACE = "DSpace";

    private static final String aliases[] = { NAMESPACE };

    /**
     * Typically returns 1 element, the Namespace name of the implementation's registry
     */
    public static String [] getPluginNames()
    {
        return aliases;
    }

    public String getNamespace()
    {
        return aliases[0];
    }
}
