package org.dspace.content.format;

/**
 * Implementation of the Provisional registry, intended for those
 * formats not found in any external registry (yet?) but still needed
 * by the local DSpace.
 * See the documentation in BuiltinFormatRegistry for details.
 * <p>
 * Configuration entries:
 *   # path to registry contents in XML:
 *   formatRegistry.Provisional.document = ${dspace.dir}/config/formats/provisional-formats.xml
 *   # whether or not to validate registry when loading it
 *   formatRegistry.Provisional.validate = true
 *   # path to schema with which to validate
 *   formatRegistry.Provisional.schema = ${dspace.dir}/config/formats/formats.xsd
 *   # Default value of supportLevel on newly created/imported BSFs,
 *   # must be one of "unknown" | "known" | "supported"
 *   formatRegistry.Provisional.defaultSupportLevel = unknown
 * <p>
 * @author Larry Stone
 * @version $Revision: 1323 $
 * @see BuiltinFormatRegistry
 */
public class ProvisionalFormatRegistry extends BuiltinFormatRegistry
{
    public static final String NAMESPACE = "Provisional";

    private static final String aliases[] = { NAMESPACE };

    /**
     * Typically returns 1 element, the Namespace name of the implementation's registry
     */
    public static String [] getPluginNames()
    {
        return aliases;
    }

    public String getNamespace()
    {
        return aliases[0];
    }
}
