--
-- database_schema_15-16.sql
--
-- Version: $$
--
-- Date:    $Date:$
--
-- Copyright (c) 2002-2007, Hewlett-Packard Company and Massachusetts
-- Institute of Technology.  All rights reserved.
--
-- Redistribution and use in source and binary forms, with or without
-- modification, are permitted provided that the following conditions are
-- met:
--
-- - Redistributions of source code must retain the above copyright
-- notice, this list of conditions and the following disclaimer.
--
-- - Redistributions in binary form must reproduce the above copyright
-- notice, this list of conditions and the following disclaimer in the
-- documentation and/or other materials provided with the distribution.
--
-- - Neither the name of the Hewlett-Packard Company nor the name of the
-- Massachusetts Institute of Technology nor the names of their
-- contributors may be used to endorse or promote products derived from
-- this software without specific prior written permission.
--
-- THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
-- ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
-- LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
-- A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
-- HOLDERS OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
-- INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
-- BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS
-- OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
-- ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR
-- TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE
-- USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH
-- DAMAGE.

--
-- SQL commands to upgrade the database schema of a live DSpace 1.5
-- to the DSpace 1.6 database schema
--
-- DUMP YOUR DATABASE FIRST. DUMP YOUR DATABASE FIRST. DUMP YOUR DATABASE FIRST. DUMP YOUR DATABASE FIRST.
-- DUMP YOUR DATABASE FIRST. DUMP YOUR DATABASE FIRST. DUMP YOUR DATABASE FIRST. DUMP YOUR DATABASE FIRST.
-- DUMP YOUR DATABASE FIRST. DUMP YOUR DATABASE FIRST. DUMP YOUR DATABASE FIRST. DUMP YOUR DATABASE FIRST.

--++++++++++++++++++++++++++++++++++++++++++++++++++++
------------------------------------------------------
-- Changes for BitstreamFormat Renovation
------------------------------------------------------
--++++++++++++++++++++++++++++++++++++++++++++++++++++


--++++++++++++++++++++++++++++++++++++++++++++++++++++
-- 1. add ExternalFormatNamespace table
--++++++++++++++++++++++++++++++++++++++++++++++++++++

------------------------------------------------------
-- ExternalFormatNamespace table, for efficient storage and comparison of External Format Identifier namespaces
------------------------------------------------------
CREATE SEQUENCE externalformatnamespace_seq;
CREATE TABLE ExternalFormatNamespace
(
  namespace_id INTEGER PRIMARY KEY,
  namespace VARCHAR(128)
);

--++++++++++++++++++++++++++++++++++++++++++++++++++++
-- 2. add new BitstreamFormat table and support
--++++++++++++++++++++++++++++++++++++++++++++++++++++

------------------------------------------------------
-- BitstreamFormat table, a cache of references to technical metadata in external format registries
------------------------------------------------------
CREATE SEQUENCE bitstreamformat_seq;
CREATE TABLE BitstreamFormat
(
  bitstream_format_id   INTEGER PRIMARY KEY,
  name                  VARCHAR(128),
  description           TEXT,
  mimetype              VARCHAR(128),
  support_level         INTEGER,
  canonical_extension   VARCHAR(40),
  override_name                  BOOLEAN DEFAULT FALSE,
  override_description           BOOLEAN DEFAULT FALSE,
  override_mimetype              BOOLEAN DEFAULT FALSE,
  override_canonical_extension   BOOLEAN DEFAULT FALSE
);

------------------------------------------------------
-- ExternalFormatIdentifier table, map of BitstreamFormat entry to namespaced external identifier
------------------------------------------------------
CREATE SEQUENCE externalformatidentifier_seq;
CREATE TABLE ExternalFormatIdentifier
(
  external_format_id INTEGER PRIMARY KEY,
  bitstream_format_id
    INTEGER REFERENCES BitstreamFormat(bitstream_format_id),
  namespace_id INTEGER REFERENCES ExternalFormatNamespace(namespace_id),
  external_identifier VARCHAR(128),
  last_imported         TIMESTAMP WITH TIME ZONE
);

ALTER TABLE ExternalFormatIdentifier ADD CONSTRAINT identifier_uniqueness
    UNIQUE (namespace_id, external_identifier);


--++++++++++++++++++++++++++++++++++++++++++++++++++++
-- 3. Start changing over to new schema by moving old Bitstream reference to BSF, adding new column.
--++++++++++++++++++++++++++++++++++++++++++++++++++++

ALTER TABLE Bitstream RENAME COLUMN bitstream_format_id TO
 old_bitstream_format_id;

ALTER TABLE Bitstream ADD COLUMN bitstream_format_id
    INTEGER REFERENCES BitstreamFormat(bitstream_format_id);

--++++++++++++++++++++++++++++++++++++++++++++++++++++
-- 4. Add "confidence" and "source" (with its table of normalized values) to Bitstream too
--++++++++++++++++++++++++++++++++++++++++++++++++++++

ALTER TABLE Bitstream ADD COLUMN format_confidence INTEGER DEFAULT 0;

------------------------------------------------------
-- FormatSource table, normalized values of format_source column since we can expect much repetition.
------------------------------------------------------
CREATE SEQUENCE formatsource_seq;
CREATE TABLE FormatSource
(
  format_source_id INTEGER PRIMARY KEY,
  format_source VARCHAR(256) UNIQUE
);

ALTER TABLE Bitstream ADD COLUMN format_source_id  INTEGER
    REFERENCES FormatSource(format_source_id);

-- End of BitstreamFormat Renovation changes. --
